%bcond_with doc

Name: freetds
Version: 1.2.18
Release: 3
Summary: Implementation of the TDS (Tabular DataStream) protocol

# binaries are GPL-2.0-or-later see COPYING.txt
License: GPL-3.0-or-later
URL: https://www.freetds.org/
Source0: https://www.freetds.org/files/stable/%{name}-%{version}.tar.bz2

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: pkg-config
BuildRequires: gettext-tools

BuildRequires: libiconv-devel
BuildRequires: unixODBC-devel

%description
FreeTDS is a project to document and implement the TDS (Tabular
DataStream) protocol. TDS is used by Sybase(TM) and Microsoft(TM) for
client to database server communications. FreeTDS includes call
level interfaces for DB-Lib, CT-Lib, and ODBC.

%package -n libct4
Summary: libct4 shared library
# Libraries are LGPL-2.0-or-later See COPYING.LIB.txt
License: LGPL-3.0-or-later

%description -n libct4
libct4 shared library
        
%package -n libsybdb5
Summary: libsybdb5 shared library
# Libraries are LGPL-2.0-or-later See COPYING.LIB.txt
License: LGPL-3.0-or-later
Conflicts: libsydb5
Obsoletes: libsydb5
Conflicts: freetds-config
Obsoletes: freetds-config

%description -n libsybdb5
libsybdb5 shared library

%package odbc
Summary: FreeTDS ODBC driver and related files
# Libraries are LGPL-2.0-or-later See COPYING.LIB.txt
License: LGPL-3.0-or-later
Requires(pre): %{_bindir}/odbcinst
Requires(post): %{_bindir}/odbcinst
Requires(preun): %{_bindir}/odbcinst
Conflicts: libtdsodbc0
Obsoletes: libtdsodbc0

%description odbc
FreeTDS ODBC driver and related files

%package devel
# Libraries are LGPL-2.0-or-later See COPYING.LIB.txt
License: LGPL-3.0-or-later
Summary: Header files and development libraries for freetds
Requires: libct4 = %{version}-%{release}
Requires: libsybdb5 = %{version}-%{release}
 
%description devel
The freetds-devel package contains the files necessary for development with 
the FreeTDS libraries. 

%if %{with doc}
%package doc
Summary: Development documentation for freetds
BuildArch: noarch
 
%description doc
The freetds-doc package contains the userguide and reference of FreeTDS 
and can be installed even if FreeTDS main package is not installed
%endif

%prep
%setup -q

%build
autoreconf -fiv

%configure \
 CFLAGS="$CFLAGS -Wno-attributes" \
 LDFLAGS="-Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
 --with-aix-soname=svr4 \
 --enable-shared \
 --disable-static \
 --with-libiconv-prefix=%{_prefix} \
 --with-unixodbc=%{_prefix} \
#end

%make_build

# Many of the unittests fail as it requires a connection to mssql server db
# See http://www.freetds.org/userguide/ConfirmInstall.html#Tests

# ======================================================
#   FreeTDS 1.2.18: src/tds/unittests/test-suite.log
#======================================================

# TOTAL: 25
# PASS:  8
# SKIP:  0
# XFAIL: 0
# FAIL:  17
# XPASS: 0
# ERROR: 0

# FAIL: t0001
# ===========

# tds_connect_and_login() failed
# try_tds_login() failed
# t0001.c: Testing login, logout
# FAIL t0001 (exit status: 1)

%check
VERBOSE=1 make check

%install
%make_install

# Convert the svr4-style library to a bare shared object so unixODBC can load it
ar -X64 -x %{buildroot}%{_libdir}/libtdsodbc.so.0 shr_64.o
mv shr_64.o %{buildroot}%{_libdir}/libtdsodbc.so
rm %{buildroot}%{_libdir}/libtdsodbc.so.0

# Create a registration file to handle driver install
mkdir -p %{buildroot}%{_datadir}/freetds

cat<<EOF > %{buildroot}%{_datadir}/freetds/unixodbcregistration
[FreeTDS]
Description=Free Sybase & MS SQL Driver
Driver=%{_libdir}/libtdsodbc.so
EOF

%if ! %{with doc}
rm -r %{buildroot}%{_datadir}/doc/%{name}/
%endif

%pre
# ##############################################################################
# # processing before the install
# $1 = 1: install
# $1 = 2+: upgrade
# ##############################################################################

# install is no-op, we only care about upgrades
[ $1 -gt 1 ] || exit 0

# If we're upgrading, we should de-register the existing driver in case it has
# changed.
%{_bindir}/odbcinst -u -d -n 'FreeTDS'

%post odbc
################################################################################
# processing after the install
# $1 = 1: install
# $1 = 2+: upgrade
################################################################################

# register the new driver
%{_bindir}/odbcinst -i -d -f %{_datadir}/freetds/unixodbcregistration
if [ $? -ne 0 ]; then
  echo "Driver registration failed"
  echo "The driver registration can be re-attempted by running the following command:"
  echo "/QOpenSys/pkgs/bin/odbcinst -i -d -f /QOpenSys/pkgs/share/freetds/unixodbcregistration"
fi

%preun odbc
################################################################################
# processing before the uninstall
# $1 = 0: uninstall
# $1 = 1: upgrade
################################################################################
# upgrade is handled in post, we only care about uninstall

[ $1 -eq 1 ] && exit 0

# If we're uninstall, we should de-register the existing driver
%{_bindir}/odbcinst -u -d -n 'FreeTDS'

%files
%defattr(-, qsys, *none)
%license COPYING.txt
%doc README.md
%doc AUTHORS.md
%{_bindir}/bsqldb
%{_bindir}/datacopy
%{_bindir}/defncopy
%{_bindir}/fisql
%{_bindir}/freebcp
%{_bindir}/tdspool
%{_bindir}/tsql

%exclude %{_mandir}/man1/bsqlodbc.1.*
%exclude %{_mandir}/man1/osql.1.*

%{_mandir}/man1/*

%files -n libct4
%defattr(-, qsys, *none)
%license COPYING_LIB.txt
%{_libdir}/libct.so.4

%files -n libsybdb5
%defattr(-, qsys, *none)
%license COPYING_LIB.txt
%{_libdir}/libsybdb.so.5

%config(noreplace) %{_sysconfdir}/freetds.conf
%config(noreplace) %{_sysconfdir}/locales.conf
%config(noreplace) %{_sysconfdir}/pool.conf

%{_mandir}/man5/freetds.conf.5*

%files odbc
%defattr(-, qsys, *none)
%license COPYING_LIB.txt
%{_bindir}/bsqlodbc
%{_bindir}/osql

%{_mandir}/man1/bsqlodbc.1.*
%{_mandir}/man1/osql.1.*

%{_libdir}/libtdsodbc.so

%dir %{_datadir}/freetds/
%{_datadir}/freetds/unixodbcregistration

%files devel
%defattr(-, qsys, *none)
%{_libdir}/libct.so
%{_libdir}/libsybdb.so
%{_includedir}/*

%if %{with doc}
%files doc
%defattr(-, qsys, *none)
%doc %{_datadir}/doc/%{name}/reference
%doc %{_datadir}/doc/%{name}/images
%doc %{_datadir}/doc/%{name}/userguide
%endif

%changelog
* Tue Apr 27 2021 Abdirahim Musse <abdirahim.musse@ibm.com> - 1.2.18
- Fix typo in subpackage name libsydb5 -> libsybdb5
- Move config files from devel to libsybdb5 package

* Tue Jan 12 2021 Abdirahim Musse <abdirahim.musse@ibm.com>
- Initial spec
